/*
 * MMap+ - 3d image viewer
 * Copyright 2005, 2006 Masahide Miyake
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __GLAREA_H__
#define __GLAREA_H__

GtkWidget *glarea_create (void);
void glarea_process_start (void);
void glarea_force_render (void);
void glarea_force_update_and_render (void);
void glarea_get_size (gint * w, gint * h);

gboolean glarea_gl_begin (void);
void glarea_gl_end (void);

gint glarea_get_texture_format (void);
gboolean glarea_is_support_compress (void);
gboolean glarea_is_support_vbo (void);
gboolean glarea_is_direct (void);

void glarea_tilt_lock (gboolean bool);

gint glarea_get_max_texture_size (void);

void glarea_process_start (void);

void glarea_saveimage (void);
void glarea_render_file (void);	/* 画像の出力用 */

#endif /* __GLAREA_H__ */
